@@ -32,11 +32,10 @@ from Andreani_QA_parameters.Parameters import Parameters
 from Andreani_QA_Functions.Functions import Functions
 
 if platform.system() == "Windows":
-    from win32com.client import Dispatch
     from Andreani_QA_Debugger.Debugger import Debugger
 
 ####RECORDER####
-import os, time, re
+import time, re
 from timeit import default_timer
 from datetime import timedelta
 import cv2
@@ -64,7 +63,7 @@ class Selenium(Functions, Parameters):
     message_error = None
     json_on_loaded = None
     global_date = time.strftime(
-        Parameters.date_format)  # formato dd/mm/aaaa    global_time = time.strftime(Parameters.time_format)  # formato 24 houras
+        Parameters.date_format)  # formato dd/mm/aaaa global_time = time.strftime(Parameters.time_format)  # formato 24 houras
     lista_pasos = []
     lista_descripcion_pasos = []
     driver_port_status = False
@@ -77,7 +76,7 @@ class Selenium(Functions, Parameters):
 
     # INICIALIZA LOS DRIVER Y LOS CONFIGURA
     def open_browser(self, url=None, browser=Parameters.browser, options_headless=Parameters.headless,
-                     download_path=None, record=None):
+                     download_path=None, record=None, privated=True):
 
         """
             Description:
@@ -93,26 +92,28 @@ class Selenium(Functions, Parameters):
                     -El directorio base
                     -El navegador utilizado
         """
-        print(f"system: {os.getenv('PYBOT_SYSTEM')}")
         print(f"Directorio Base: {Parameters.current_path}")
         print(f"{self.color_message('YELLOW', 'AGUARDANDO:')} Inicio del navegador "
               f"'{self.color_message('BLUE', browser)}'.")
         options = None
         if browser == "CHROME":
             options = webdriver.ChromeOptions()
-            options.add_argument("--incognito")
             options.add_argument(f"--cpu-throttle=10")
             if download_path is None:
                 download_default = {"download.default_directory": self.path_downloads}
                 options.add_experimental_option("prefs", download_default)
             else:
                 options.add_experimental_option("prefs", {"download.default_directory": download_path})
+            if privated:
+                options.add_argument("--incognito")
         if browser == "EDGE":
             options = EdgeOptions()
-            options.add_argument("--inprivate")
+            if privated:
+                options.add_argument("--inprivate")
         if browser == "FIREFOX":
             options = FirefoxOptions()
-            options.add_argument("--private")
+            if privated:
+                options.add_argument("--private")
         if browser == "IE":
             options = IeOptions()
         options.add_argument("--no-sandbox")
@@ -127,8 +128,6 @@ class Selenium(Functions, Parameters):
         options.add_argument("--proxy-server='direct://'")
         options.add_argument("--proxy-bypass-list=*")
         options.add_argument("--disable-gpu") if os.name == "nt" else None
-        # if browser != "FIREFOX":
-        # options.add_argument("--profile-directory=Temporal")
         if Parameters.environment == "Linux":
             options.add_argument("--headless")
             Selenium.set_exception_loggin(True)
@@ -139,21 +138,18 @@ class Selenium(Functions, Parameters):
                 Selenium.driver.maximize_window()
 
         if Parameters.environment == "Windows":
-            if Parameters.environment_configuration is None:
+            if Parameters.environment_configuration == "standalone":
                 options.add_argument(f"--remote-debugging-port={Selenium.available_port()}")
                 Selenium.set_mode_debug(False)
-                Selenium.select_browser(self, browser, options)
-                Selenium.initialize_browser(self, url, record)
-                Selenium.driver.maximize_window()
-            else:
-                if options_headless or Parameters.environment_configuration.lower() == "server":
-                    print("La ejecucion se realizara en modo headless.")
-                    options.add_argument("--headless")
-                    Selenium.set_exception_loggin(True)
-                    Selenium.select_browser(self, browser, options)
-                    Selenium.initialize_browser(self, url, record)
-                    Selenium.set_mode_debug(False)
-                    Selenium.set_highlight(False)
+
+            if options_headless or Parameters.environment_configuration == "server":
+                options.add_argument("--headless")
+                Selenium.set_exception_loggin(True)
+                Selenium.set_mode_debug(False)
+                Selenium.set_highlight(False)
+            Selenium.select_browser(self, browser, options)
+            Selenium.initialize_browser(self, url, record)
+            Selenium.driver.maximize_window()
             return Selenium.driver
 
     def initialize_browser(self, url, record=False):
@@ -198,21 +194,23 @@ class Selenium(Functions, Parameters):
 
         try:
             if browser == "CHROME":
-                if Parameters.environment_configuration.lower() == "server":
-                    # custom_chrome_path = 'C:\Chromium\chrome.exe'
-                    # options.binary_location = custom_chrome_path
-                    print("Ejecutando Chromium en server.")
-                    Selenium.driver = webdriver.Chrome(options=options)
+                if Parameters.environment_configuration == "server":
+                    custom_chrome_path = 'C:\Chromium\chrome.exe'
+                    options.binary_location = custom_chrome_path
+                    Selenium.driver = webdriver.Chrome(service=self.chrome_services, options=options)
                 else:
-                    Selenium.driver = webdriver.Chrome(options=options)
+                    Selenium.driver = webdriver.Chrome(service=self.chrome_services, options=options)
 
             elif browser == "FIREFOX":
                 Selenium.driver = webdriver.Firefox(service=self.firefox_services, options=options)
+
             elif browser == "IE":
                 Selenium.driver = webdriver.Ie(service=self.ie_services, options=options)
+
             elif browser == "EDGE":
                 Selenium.driver = webdriver.Edge(service=self.edge_services, options=options)
             Selenium.pid = Selenium.driver.service.process.pid
+
         except Exception as e:
             Functions.exception_logger(e)
             Selenium.tear_down(self)
